@@ -20,9 +20,9 @@
 
 from functools import cached_property
 
-from .gobject_object import Object
-from .response_id import ExtResponse
 from .common import *
+from .gobject_object import Object
+from .response_id import ExtResponse, decompile_response_type
 
 ALLOWED_PARENTS: T.List[T.Tuple[str, str]] = [
     ("Gtk", "Buildable"),
@@ -88,7 +88,7 @@ class Child(AstNode):
                 hints = [
                     "only Gio.ListStore or Gtk.Buildable implementors can have children"
                 ]
-                if "child" in gir_class.properties:
+                if hasattr(gir_class, "properties") and "child" in gir_class.properties:
                     hints.append(
                         "did you mean to assign this object to the 'child' property?"
                     )
@@ -127,10 +127,15 @@ class Child(AstNode):
                 )
 
 
-@decompiler("child")
-def decompile_child(ctx, gir, type=None, internal_child=None):
-    if type is not None:
+@decompiler("child", element=True)
+def decompile_child(ctx, gir, element):
+    if type := element["type"]:
+        if type == "action":
+            if decompiled := decompile_response_type(ctx.parent_node, element):
+                ctx.print(decompiled)
+                return
+
         ctx.print(f"[{type}]")
-    elif internal_child is not None:
+    elif internal_child := element["internal-child"]:
         ctx.print(f"[internal-child {internal_child}]")
     return gir
